summaryrefslogtreecommitdiff
path: root/config/p10k-rainbow.zsh
diff options
context:
space:
mode:
Diffstat (limited to 'config/p10k-rainbow.zsh')
-rw-r--r--config/p10k-rainbow.zsh12
1 files changed, 6 insertions, 6 deletions
diff --git a/config/p10k-rainbow.zsh b/config/p10k-rainbow.zsh
index 35c7e91d..49f6ffba 100644
--- a/config/p10k-rainbow.zsh
+++ b/config/p10k-rainbow.zsh
@@ -218,17 +218,17 @@
# Current directory background color.
# typeset -g POWERLEVEL9K_DIR_BACKGROUND=4
# Default current directory foreground color.
- typeset -g POWERLEVEL9K_DIR_FOREGROUND=0
+ typeset -g POWERLEVEL9K_DIR_FOREGROUND=254
# If directory is too long, shorten some of its segments to the shortest possible unique
# prefix. The shortened directory can be tab-completed to the original.
typeset -g POWERLEVEL9K_SHORTEN_STRATEGY=truncate_to_unique
# Replace removed segment suffixes with this symbol.
typeset -g POWERLEVEL9K_SHORTEN_DELIMITER=
# Color of the shortened directory segments.
- typeset -g POWERLEVEL9K_DIR_SHORTENED_FOREGROUND=8
+ typeset -g POWERLEVEL9K_DIR_SHORTENED_FOREGROUND=250
# Color of the anchor directory segments. Anchor segments are never shortened. The first
# segment is always an anchor.
- typeset -g POWERLEVEL9K_DIR_ANCHOR_FOREGROUND=0
+ typeset -g POWERLEVEL9K_DIR_ANCHOR_FOREGROUND=255
# Display anchor directory segments in bold.
typeset -g POWERLEVEL9K_DIR_ANCHOR_BOLD=true
# Don't shorten directories that contain any of these files. They are anchors.
@@ -309,9 +309,9 @@
# to have its own color.
#
# typeset -g POWERLEVEL9K_DIR_WORK_BACKGROUND=4
# typeset -g POWERLEVEL9K_DIR_WORK_FOREGROUND=0
# typeset -g POWERLEVEL9K_DIR_WORK_SHORTENED_FOREGROUND=8
# typeset -g POWERLEVEL9K_DIR_WORK_ANCHOR_FOREGROUND=0
#
# typeset -g POWERLEVEL9K_DIR_CLASSES=()
@@ -309,9 +309,9 @@
#
# typeset -g POWERLEVEL9K_DIR_WORK_BACKGROUND=4
- # typeset -g POWERLEVEL9K_DIR_WORK_FOREGROUND=0
- # typeset -g POWERLEVEL9K_DIR_WORK_SHORTENED_FOREGROUND=8
- # typeset -g POWERLEVEL9K_DIR_WORK_ANCHOR_FOREGROUND=0
+ # typeset -g POWERLEVEL9K_DIR_WORK_FOREGROUND=254
+ # typeset -g POWERLEVEL9K_DIR_WORK_SHORTENED_FOREGROUND=250
+ # typeset -g POWERLEVEL9K_DIR_WORK_ANCHOR_FOREGROUND=255
#
# typeset -g POWERLEVEL9K_DIR_CLASSES=()